@@ -1,4 +1,4 @@
-/* 
+/*
  Copyright (C) 2021 Momi-g
 
  This program is free software; you can redistribute it and/or modify
@@ -15,23 +15,23 @@
  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-/*-*
-@_name	ped_main
-@_brief	ped runner
-@synopsis	-
-@_eg	-
-@_func -
-@_param	-
-@_param	-
-@_return	-
-@_details	-
-@bugs -
-@see_also -
-@_note
-@conforming_to posix-2001+
-@version 2021-07-29
-@_auther momi-g
--*/
+/*SH_doc
+title=ped section=1
+@name	ped
+@_brief	sed-style editer using peg
+@synopsis
+	ped [-e str|-f rulefile] [-n|N] [-r|R] [-t|T] [-hHgVodEL] file/stdin
+@tl;dr
+	@(code)@
+	~$ echo "12a"|ped -re 'ID<-[a-z]+ {_1="Z"}'
+		>>> 12Z
+	@()
+@_desc
+	see ~$ ped -h or -H
+@copyright
+	Copyright (C) 2021 Momi-g --
+	License GPLv3+ <https://gnu.org/licenses/gpl.html>.
+//SH_docE*/
 #ifndef ped_main_5906e77bc764
 #define ped_main_5906e77bc764
 //no header. runner src only
